@@ -29,18 +29,20 @@ import socket
 from telnetlib import Telnet
 from typing import Any, Dict, List, Optional
 
-__version__ = '0.0.1'
+__version__ = '0.0.4'
 __all__ = ['PyNUT3Error', 'PyNUT3Client']
 
 _LOGGER = logging.getLogger(__name__)
 
 
 class PyNUT3Error(Exception):
-    """Base class for custom exceptions."""
+    """Base class for custom exceptions.
+    """
+    # pylint: disable=unnecessary-pass
     pass
 
 
-class PyNUT3Client(object):
+class PyNUT3Client:
     """Access NUT (Network UPS Tools) servers."""
 
     def __init__(self, host: str = '127.0.0.1', port: int = 3493,
@@ -60,7 +62,7 @@ class PyNUT3Client(object):
                         when calling each method
         """
 
-        _LOGGER.debug('NUT Class initialization, Host/Port: %s:%s, Login: %s', host, port, login)
+        _LOGGER.debug(f'NUT Class initialization, Host/Port: {host}:{port}, Login: {login}')
 
         self._host: str = host
         self._port: int = port
@@ -74,7 +76,7 @@ class PyNUT3Client(object):
             self._connect()
 
     def __del__(self) -> None:
-        # Try to disconnect cleanly when class is deleted.
+        """Try to disconnect cleanly when class is deleted."""
         _LOGGER.debug('NUT Class deleted, trying to disconnect.')
         self._disconnect()
 
@@ -115,8 +117,8 @@ class PyNUT3Client(object):
                 result = self._read_until('\n')
                 if result != 'OK\n':
                     raise PyNUT3Error(result.replace('\n', ''))
-        except socket.error:
-            raise PyNUT3Error('Socket error.')
+        except socket.error as exc:
+            raise PyNUT3Error('Socket error.') from exc
 
     def _read_until(self, string: str) -> str:
         """ Wrapper for _srv_handler read_until method."""
@@ -133,13 +135,14 @@ class PyNUT3Client(object):
         try:
             if self._srv_handler is None:
                 raise RuntimeError('NUT3 connection has not been opened.')
-            return self._srv_handler.write(string.encode('ascii'))
+            self._srv_handler.write(string.encode('ascii'))
+            return
         except (EOFError, BrokenPipeError):
             _LOGGER.error('NUT3 problem writing to server.')
 
     def description(self, ups: str) -> str:
         """Returns the description for a given UPS."""
-        _LOGGER.debug('NUT3 requesting description from server %s', self._host)
+        _LOGGER.debug(f'NUT3 requesting description from server {self._host}')
 
         if not self._persistent:
             self._connect()
@@ -152,8 +155,8 @@ class PyNUT3Client(object):
 
         try:
             return result.split('"')[1].strip()
-        except IndexError:
-            raise PyNUT3Error(result.replace('\n', ''))
+        except IndexError as exc:
+            raise PyNUT3Error(result.replace('\n', '')) from exc
 
     def list_ups(self) -> Dict[str, str]:
         """Returns the list of available UPS from the NUT server.
@@ -161,7 +164,7 @@ class PyNUT3Client(object):
         The result is a dictionary containing 'key->val' pairs of
         'UPSName' and 'UPS Description'.
         """
-        _LOGGER.debug('NUT3 requesting list_ups from server %s', self._host)
+        _LOGGER.debug(f'NUT3 requesting list_ups from server {self._host}')
 
         if not self._persistent:
             self._connect()
@@ -196,7 +199,7 @@ class PyNUT3Client(object):
         The result is a dictionary containing 'key->val' pairs of all
         available vars.
         """
-        _LOGGER.debug("NUT3 requesting list_vars from server %s", self._host)
+        _LOGGER.debug(f"NUT3 requesting list_vars from server {self._host}")
 
         if not self._persistent:
             self._connect()
@@ -232,8 +235,7 @@ class PyNUT3Client(object):
         The result is a dict object with command name as key and a description
         of the command as value.
         """
-        _LOGGER.debug("NUT3 requesting list_commands from server %s",
-                      self._host)
+        _LOGGER.debug(f"NUT3 requesting list_commands from server {self._host}")
 
         if not self._persistent:
             self._connect()
@@ -278,8 +280,7 @@ class PyNUT3Client(object):
         The result is a dictionary containing 'key->val' pairs of
         'UPSName' and a list of clients.
         """
-        _LOGGER.debug("NUT3 requesting list_clients from server %s",
-                      self._host)
+        _LOGGER.debug(f"NUT3 requesting list_clients from server {self._host}")
 
         if not self._persistent:
             self._connect()
@@ -321,7 +322,7 @@ class PyNUT3Client(object):
         The result is presented as a dictionary containing 'key->val'
         pairs.
         """
-        _LOGGER.debug("NUT3 requesting list_rw_vars from server %s", self._host)
+        _LOGGER.debug(f"NUT3 requesting list_rw_vars from server {self._host}")
 
         if not self._persistent:
             self._connect()
@@ -355,7 +356,7 @@ class PyNUT3Client(object):
 
         The result is presented as a list.
         """
-        _LOGGER.debug("NUT3 requesting list_enum from server %s", self._host)
+        _LOGGER.debug(f"NUT3 requesting list_enum from server {self._host}")
 
         if not self._persistent:
             self._connect()
@@ -376,15 +377,15 @@ class PyNUT3Client(object):
             return [c[offset:].split('"')[1].strip()
                     for c in result[:end_offset].split('\n')
                     if '"' in c[offset:]]
-        except IndexError:
-            raise PyNUT3Error(result.replace('\n', ''))
+        except IndexError as exc:
+            raise PyNUT3Error(result.replace('\n', '')) from exc
 
     def list_range(self, ups: str, var: str) -> List[str]:
         """Get a list of valid values for an range variable.
 
         The result is presented as a list.
         """
-        _LOGGER.debug("NUT3 requesting list_range from server %s", self._host)
+        _LOGGER.debug(f"NUT3 requesting list_range from server {self._host}")
 
         if not self._persistent:
             self._connect()
@@ -405,8 +406,8 @@ class PyNUT3Client(object):
             return [c[offset:].split('"')[1].strip()
                     for c in result[:end_offset].split('\n')
                     if '"' in c[offset:]]
-        except IndexError:
-            raise PyNUT3Error(result.replace('\n', ''))
+        except IndexError as exc:
+            raise PyNUT3Error(result.replace('\n', '')) from exc
 
     def set_var(self, ups: str, var: str, value: str) -> None:
         """Set a variable to the specified value on selected UPS.
@@ -414,7 +415,7 @@ class PyNUT3Client(object):
         The variable must be a writable value (cf list_rw_vars) and you
         must have the proper rights to set it (maybe login/password).
         """
-        _LOGGER.debug("NUT3 setting set_var '%s' on '%s' to '%s'", var, self._host, value)
+        _LOGGER.debug(f"NUT3 setting set_var '{var}' on '{self._host}' to '{value}'")
 
         if not self._persistent:
             self._connect()
@@ -430,7 +431,7 @@ class PyNUT3Client(object):
 
     def get_var(self, ups: str, var: str) -> str:
         """Get the value of a variable."""
-        _LOGGER.debug("NUT3 requesting get_var '%s' on '%s'.", var, self._host)
+        _LOGGER.debug(f"NUT3 requesting get_var '{var}' on '{self._host}'.")
 
         if not self._persistent:
             self._connect()
@@ -443,8 +444,8 @@ class PyNUT3Client(object):
 
         try:
             return result.split('"')[1].strip()
-        except IndexError:
-            raise PyNUT3Error(result.replace('\n', ''))
+        except IndexError as exc:
+            raise PyNUT3Error(result.replace('\n', '')) from exc
 
     # Alias for convenience
     def get(self, ups: str, var: str) -> str:
@@ -453,7 +454,7 @@ class PyNUT3Client(object):
 
     def var_description(self, ups: str, var: str) -> str:
         """Get a variable's description."""
-        _LOGGER.debug("NUT3 requesting var_description '%s' on '%s'.", var, self._host)
+        _LOGGER.debug(f"NUT3 requesting var_description '{var}' on '{self._host}'.")
 
         if not self._persistent:
             self._connect()
@@ -466,12 +467,12 @@ class PyNUT3Client(object):
 
         try:
             return result.split('"')[1].strip()
-        except IndexError:
-            raise PyNUT3Error(result.replace('\n', ''))
+        except IndexError as exc:
+            raise PyNUT3Error(result.replace('\n', '')) from exc
 
     def var_type(self, ups: str, var: str) -> str:
         """Get a variable's type."""
-        _LOGGER.debug("NUT3 requesting var_type '%s' on '%s'.", var, self._host)
+        _LOGGER.debug(f"NUT3 requesting var_type '{var}' on '{self._host}'.")
 
         if not self._persistent:
             self._connect()
@@ -488,12 +489,12 @@ class PyNUT3Client(object):
             assert len(type_) > 0
             assert result.startswith('TYPE')
             return type_
-        except AssertionError:
-            raise PyNUT3Error(result.replace('\n', ''))
+        except AssertionError as exc:
+            raise PyNUT3Error(result.replace('\n', '')) from exc
 
     def command_description(self, ups: str, command: str) -> str:
         """Get a command's description."""
-        _LOGGER.debug("NUT3 requesting command_description '%s' on '%s'.", command, self._host)
+        _LOGGER.debug(f"NUT3 requesting command_description '{command}' on '{self._host}'.")
 
         if not self._persistent:
             self._connect()
@@ -506,12 +507,12 @@ class PyNUT3Client(object):
 
         try:
             return result.split('"')[1].strip()
-        except IndexError:
-            raise PyNUT3Error(result.replace('\n', ''))
+        except IndexError as exc:
+            raise PyNUT3Error(result.replace('\n', '')) from exc
 
     def run_command(self, ups: str, command: str) -> None:
         """Send a command to the specified UPS."""
-        _LOGGER.debug("NUT3 run_command called '%s' on '%s'.", command, self._host)
+        _LOGGER.debug(f"NUT3 run_command called '{command}' on '{self._host}'.")
 
         if not self._persistent:
             self._connect()
@@ -527,7 +528,7 @@ class PyNUT3Client(object):
 
     def fsd(self, ups: str) -> None:
         """Send MASTER and FSD commands."""
-        _LOGGER.debug("NUT3 MASTER called on '%s'.", self._host)
+        _LOGGER.debug("NUT3 MASTER called on '{self._host}'.")
 
         if not self._persistent:
             self._connect()
@@ -535,7 +536,7 @@ class PyNUT3Client(object):
         self._write(f'MASTER {ups}\n')
         result: str = self._read_until('\n')
         if result != 'OK MASTER-GRANTED\n':
-            raise PyNUT3Error(('Master level function are not available', ''))
+            raise PyNUT3Error(('Master level functions are not available', ''))
 
         _LOGGER.debug('FSD called...')
         self._write(f'FSD {ups}\n')
@@ -550,7 +551,7 @@ class PyNUT3Client(object):
         """Send GET NUMLOGINS command to get the number of users logged
         into a given UPS.
         """
-        _LOGGER.debug("NUT3 requesting num_logins called on '%s'", self._host)
+        _LOGGER.debug(f"NUT3 requesting num_logins called on '{self._host}'")
 
         if not self._persistent:
             self._connect()
@@ -563,12 +564,12 @@ class PyNUT3Client(object):
 
         try:
             return int(result.split(' ')[2].strip())
-        except (ValueError, IndexError):
-            raise PyNUT3Error(result.replace('\n', ''))
+        except (ValueError, IndexError) as exc:
+            raise PyNUT3Error(result.replace('\n', '')) from exc
 
     def help(self) -> str:
         """Send HELP command."""
-        _LOGGER.debug("NUT3 HELP called on '%s'", self._host)
+        _LOGGER.debug(f"NUT3 HELP called on '{self._host}'")
 
         if not self._persistent:
             self._connect()
@@ -582,7 +583,7 @@ class PyNUT3Client(object):
 
     def ver(self) -> str:
         """Send VER command."""
-        _LOGGER.debug("NUT3 VER called on '%s'", self._host)
+        _LOGGER.debug(f"NUT3 VER called on '{self._host}'")
 
         if not self._persistent:
             self._connect()
